@@ -20,8 +20,9 @@ import pathlib
 default_config = """
 {
     "beakerx": {
+        "version": 2,
         "jvm_options": {
-            "heap_GB": "",
+            "heap_GB": null,
             "other": [],
             "properties": {}
         }
@@ -48,14 +49,36 @@ class EnvironmentSettings:
         try:
             file = open(EnvironmentSettings.config_path, 'r')
             content = file.read()
+            beakerx_settings = json.loads(content)
+            if beakerx_settings['beakerx'].get('version') is None:
+                content = EnvironmentSettings._convert_to_version_2(beakerx_settings)
         except IOError:
             content = default_config
             EnvironmentSettings.save_setting_to_file(default_config)
+        except ValueError as ex:
+            print ('Error while parsing beakerx.json: ', ex)
+            content = default_config
         else:
             file.close()
 
         return content
 
+    @staticmethod
+    def _convert_to_version_2(beakerx_settings):
+        settings = beakerx_settings['beakerx']['jvm_options']
+        new_prop = []
+        for x in settings['properties']:
+            prop = {
+                'name': x,
+                'value': settings['properties'][x]
+            }
+            new_prop.append(prop)
+        settings['properties'] = new_prop
+        if settings.get('heap_GB'):
+            settings['heap_GB'] = float(settings['heap_GB'])
+        content = json.dumps(beakerx_settings)
+        return content
+
     @staticmethod
     def read_beakerx_env_settings():
         args = []
@@ -68,13 +91,15 @@ class EnvironmentSettings:
                 args.append(x)
 
             for x in jvm_settings['properties']:
-                value = '-D' + x + '=' + jvm_settings['properties'][x]
+                name = x.get('name')
+                value = x.get('value')
+                value = '-D' + name + '=' + value
                 args.append(value)
 
             if 'heap_GB' in jvm_settings and jvm_settings['heap_GB']:
                 val = float(jvm_settings['heap_GB'])
                 if val.is_integer():
-                    value = '-Xmx' + jvm_settings['heap_GB'] + 'g'
+                    value = '-Xmx' + str(jvm_settings['heap_GB']) + 'g'
                 else:
                     value = '-Xmx' + str(int(val * 1024)) + 'm'
                 args.append(value)
